## $Id: interfaces.py 11541 2014-03-26 07:58:25Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)
from kofacustom.nigeria.utils.lgas import LGAS

_ = MessageFactory = zope.i18nmessageid.MessageFactory('kofacustom.nigeria')

high_qual = SimpleKofaVocabulary(
    ('National Certificate of Education','nce'),
    ('Pre Degree Programme','pre'),
    ('Diploma Programme','dip'),
    ('Ordinary National Diploma','ond'),
    ('Bachelors Degree','bd'),
    ('Masters Degree','md'),
    ('Professional Qualification','pq'),
    ('Other Certification','oc'),
    ('Higher National Diploma','hnd'),
    ('Post Graduate Diploma','pgd'),
    ('NCE AL OTH','nce_al_oth'),
    ('National Defence Academy','nda'),
    ('RMC','rmc'),
    ('Ph.D.(Doctor of Philosophy)','phd'),
    ('M.Phil (Master of Philosophy)','mphil'),
    ('WAEC Technical Examination','wte'),
    ('Awaiting Results','a_rslt'),
    )

high_grade = SimpleKofaVocabulary(
    ('Upper Credit','upper_credit'),
    ('Distinction','distinction'),
    ('Credit','credit'),
    ('Merit','merit'),
    ('Lower Credit','lower_credit'),
    ('First Class','first_class'),
    ('Second Class Upper','second_class_upper'),
    ('Second Class Lower','second_class_lower'),
    ('Third Class','third_class'),
    ('Pass','pass'),
    ('Awaiting Results','a_rslt'),
    ('A Levels','al'),
    ('Unclassified Certificate', 'uc'),
    )

exam_types = SimpleKofaVocabulary(
    ('SSCE','ssce'),
    ('WAEC','waec'),
    ('GCE O\' LEVEL','gce_o_level'),
    ('TC II','tc_ii'),
    ('RSA','rsa'),
    ('NABTEB','nabteb'),
    ('NECO','neco'),
    ('ACE','ace'),
    ('GCE A\' LEVEL','gce_a_level'),
    ('IGCSE','igcse'),
    )

#lgas_vocab = SimpleKofaVocabulary(
#    *sorted([(x[1],x[0]) for x in LGAS]))

class LGASource(BasicSourceFactory):
    """A source for school subjects used in exam documentation.
    """
    lga_dict = dict(LGAS)

    def getValues(self):
        return sorted(self.lga_dict.keys())

    def getToken(self, value):
        return str(value)

    def getTitle(self, value):
        return self.lga_dict.get(value,
            _('Invalid key: ${a}', mapping = {'a':value}))
